namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;
    
    [Serialized]    
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(LinkComponent))]                   
    [RequireComponent(typeof(CraftingComponent))]               
    [RequireComponent(typeof(SolidGroundComponent))]
    [RequireComponent(typeof(PowerGridComponent))]              
    [RequireComponent(typeof(PowerConsumptionComponent))]
    [RequireComponent(typeof(RoomRequirementsComponent))]
    [RequireRoomContainment]
    [RequireRoomVolume(25)]                              
    [RequireRoomMaterialTier(3, 6)]  
	
    public class HydraulicPressObject : 
        WorldObject    
    {
        public override string FriendlyName { get { return "Hydraulic Press"; } } 

		static HydraulicPressObject()
		{
			WorldObject.AddOccupancy<HydraulicPressObject>(new List<BlockOccupancy>(){
				//Bottom Right
                new BlockOccupancy(new Vector3i(0, 0, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 1, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 2, 0), typeof(BuildingWorldObjectBlock)),

				//Bottom Right
				new BlockOccupancy(new Vector3i(-1, 0, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 1, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 2, 0), typeof(BuildingWorldObjectBlock)),
				
				//Top Left
				new BlockOccupancy(new Vector3i(-1, 0, 1), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 1, 1), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 2, 1), typeof(BuildingWorldObjectBlock)),
				
				//Top Right
				new BlockOccupancy(new Vector3i(0, 0, 1), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 1, 1), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 2, 1), typeof(BuildingWorldObjectBlock)),
				
			
                });
			
		}
		
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Crafting");                                 
            this.GetComponent<PowerConsumptionComponent>().Initialize(250);                      
            this.GetComponent<PowerGridComponent>().Initialize(10, new ElectricPower()); 

        }

        public override void Destroy()
        {
            base.Destroy();
        }
       
    }

    [Serialized]
    public class HydraulicPressItem : WorldObjectItem<HydraulicPressObject>
    {
        public override string FriendlyName { get { return "Hydraulic Press"; } } 
        public override string Description  { get { return  "A machine to compress materials like Dirt."; } }

        static HydraulicPressItem()
        {
            
        }

    }

    public class HydraulicPressRecipe : Recipe
    {
        public HydraulicPressRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<HydraulicPressItem>(),
            };

            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SteelItem>(10),
                new CraftingElement<PistonItem>(1), 
				new CraftingElement<ScrewsItem>(4),
				new CraftingElement<GlassItem>(1),
            };
            SkillModifiedValue value = new SkillModifiedValue(5, MechanicsAssemblySpeedSkill.MultiplicativeStrategy, typeof(MechanicsAssemblySpeedSkill), Localizer.DoStr("craft time"));
            SkillModifiedValueManager.AddBenefitForObject(typeof(HydraulicPressRecipe), Item.Get<HydraulicPressItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<HydraulicPressItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize("Hydraulic Press", typeof(HydraulicPressRecipe));
            CraftingComponent.AddRecipe(typeof(AssemblyLineObject), this);
        }
    }
}